OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Термін дії сесії користувача несподівано завершився",
    "Provided email-address is not valid" : "Надано некоректну адресу електронної пошти ",
    "%s has published the calendar »%s«" : "%s опублікував календар »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Виникла несподівана помилка під час надсилання електронного повідомлення. Будь-ласка повідомте Вашого адміністратора.",
    "Hello," : "Вітаємо,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We wanted to inform you that %s has published the calendar »%s.",
    "Open »%s«" : "Відкрити 1%s",
    "Cheers!" : "На все добре!",
    "Calendar" : "Календар",
    "A Calendar app for Nextcloud" : "Звстосунок \"Календар\" для Nextcloud",
    "Previous day" : "Попередій день",
    "Previous week" : "Попередній тиждень",
    "Previous month" : "Попередній місяць",
    "Next day" : "Наступний день",
    "Next week" : "Наступний тиждень",
    "Next month" : "Наступний місяць",
    "+ New event" : "+ Нова подія",
    "Today" : "Сьогодні",
    "Day" : "День",
    "Week" : "Тиждень",
    "Month" : "Місяць",
    "List" : "Список",
    "Untitled calendar" : "Календар без назви",
    "Edit name" : "Редагувати назву",
    "Saving name …" : "Збереження назви ...",
    "Edit color" : "Редагувати колір",
    "Saving color …" : "Збереження кольору ...",
    "Copy private link" : "Копіювати приватне посилання",
    "Download" : "Завантажити",
    "Unshare from me" : "Від'єднати від мене",
    "Delete" : "Вилучити",
    "An error occurred, unable to change visibility of the calendar." : "Помилка: неможливо змінити відображення календаря.",
    "An error occurred, unable to delete the calendar." : "Помилка: неможливо вилучити календар.",
    "Calendar link copied to clipboard." : "Посилання на календар скопійовано",
    "Calendar link could not be copied to clipboard." : "Неможливо копіювати посилання на календар.",
    "An error occurred, unable to rename the calendar." : "Сталася помилка, неможливо перейменувати календар.",
    "An error occurred, unable to change the calendar's color." : "Сталася помилка, неможливо змінити колір календаря.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Поширення календаря буде відмінено через {countdown} секунду","Поширення календаря буде відмінено через {countdown} секунд","Поширення календаря буде відмінено через {countdown} секунд","Календар буде від'єднано за {countdown} секунд"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календар буде видалено через {countdown} секунду","Календар буде видалено через {countdown} секунд","Календар буде видалено через {countdown} секунд","Календар буде вилучено через {countdown} секунд"],
    "Share link" : "Поширити посилання",
    "Publish calendar" : "Опублікувати календар",
    "Publishing calendar" : "Публікую календар",
    "Copy public link" : "Копіювати публічне посилання",
    "Send link to calendar via email" : "Відправити посилання на календар за допомогою електронної пошти",
    "Enter one address" : "Зазначте одну адресу",
    "Sending email …" : "Надсилаю повідомлення ...",
    "Copy subscription link" : "Копіювати посилання на підписку",
    "Copying link …" : "Копіюю посилання ...",
    "Copied link" : "Копія посилання",
    "Could not copy link" : "Не вдалося cкопіювати посилання",
    "Copy embedding code" : "Копіювати код вбудування",
    "Copying code …" : "Копіюю код ...",
    "Copied code" : "Код скопійовано",
    "Could not copy code" : "Не вдалося скопіювати код",
    "Delete share link" : "Вилучити посилання для спільного використання",
    "Deleting share link …" : "Вилучення посилання для спільного використання...",
    "An error occurred, unable to publish calendar." : "Сталася помилка, неможливо опублікувати календар.",
    "An error occurred, unable to send email." : "Сталася помилка, неможливо відправити повідомлення.",
    "Embed code copied to clipboard." : "Код вбудування cкопійовано.",
    "Embed code could not be copied to clipboard." : "Неможливо копіювати код вбудування.",
    "Unpublishing calendar failed" : "Не вдалося скасувати публікацію календаря",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "No users or groups" : "Жодного користувача або групи",
    "can edit" : "може редагувати",
    "Unshare with {displayName}" : "Забрати спільний доступ з {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Сталася помилка, неможливо змінити поширення календаря.",
    "An error occurred, unable to change the permission of the share." : "Сталася помилка, неможливо змінити права доступу до поширення.",
    "+ New calendar" : "+ Новий календар",
    "New calendar" : "Новий календар",
    "Creating calendar …" : "Створюю календар ...",
    "New calendar with task list" : "Новий календар зі списком завдань",
    "New subscription from link (read-only)" : "Нова підписка з посилання (лише для читання)",
    "Creating subscription …" : "Створюю підписку ...",
    "An error occurred, unable to create the calendar." : "Сталася помилка, неможливо створити календар.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Будь-ласка, введіть корректне посилання (повинно починатися на http://, https://, webcal:// або webcals://)",
    "Untitled event" : "Подія без назви",
    "Import calendars" : "Імпортувати календарі",
    "Please select a calendar to import into …" : "Будь-ласка, оберіть у який календар виконати імпорт ...",
    "Filename" : "Ім'я файлу",
    "Calendar to import into" : "Імпортувати у цей календар",
    "Cancel" : "Скасувати",
    "_Import calendar_::_Import calendars_" : ["Імпортувати календар","Імпортувати календарі","Імпортувати календарі","Імпортувати календарі"],
    "{filename} is an unsupported file-type" : "{filename} має тип файлів, які не підтримуються",
    "{filename} could not be parsed" : "Неможливо обробити {filename}",
    "No valid files found, aborting import" : "Відсутні дійсні файли, імпортування скасовано",
    "Import partially failed. Imported {accepted} out of {total}." : "Імпорт частково не вдався. Імпортовано {accepted} з {total}",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Успішно імпортовано %n подію.","Успішно імпортовано %n подій.","Успішно імпортовано %n подій.","Успішно імпортовано %n подій."],
    "Automatic" : "Автоматично",
    "Automatic ({detected})" : "Автоматично ({detected})",
    "New setting was not saved successfully." : "Нові налаштування не було збережено.",
    "Shortcut overview" : "Перегляд скорочень",
    "or" : "або",
    "Navigation" : "Навігація",
    "Previous period" : "Попередній період",
    "Next period" : "Наступний період",
    "Views" : "Перегляди",
    "Day view" : "День",
    "Week view" : "Тиждень",
    "Month view" : "Місяць",
    "Actions" : "Дії",
    "Create event" : "Додати подію",
    "Show shortcuts" : "Показати скорочення",
    "Enable birthday calendar" : "Увімкнути календар днів народження",
    "Show tasks in calendar" : "Показувати завдання у календарі",
    "Enable simplified editor" : "Увімкнути спрощений редактор",
    "Limit visible events per view" : "Обмежити подання подій",
    "Show weekends" : "Показувати вихідні дні",
    "Show week numbers" : "Показувати номери тижнів",
    "Copy primary CalDAV address" : "Копіювати адресу основного CalDAV",
    "Copy iOS/macOS CalDAV address" : "Ккопіювати адресу iOS/macOS CalDAV",
    "Show keyboard shortcuts" : "Показати гарячі клавіші",
    "Settings & import" : "Налаштування і імпорт",
    "CalDAV link copied to clipboard." : "Посилання CalDAV скопійовано.",
    "CalDAV link could not be copied to clipboard." : "Неможливо копіювати посилання CalDAV.",
    "before at" : "до часу",
    "Notification" : "Сповіщення",
    "Email" : "Email",
    "Audio notification" : "Звукове сповіщення",
    "Other notification" : "Інше сповіщення",
    "Relative to event" : "Відносно події",
    "On date" : "У дату",
    "Edit time" : "Редагувати час",
    "Save time" : "Зберегти час",
    "Remove reminder" : "Прибрати нагадування",
    "on" : "у",
    "at" : "о",
    "+ Add reminder" : "+ Додати нагадування",
    "_second_::_seconds_" : ["секунда","секунд","секунд","секунди"],
    "_minute_::_minutes_" : ["хвилина","хвилин","хвилин","хвилини"],
    "_hour_::_hours_" : ["година","годин","годин","години"],
    "_day_::_days_" : ["день","днів","днів","дні"],
    "_week_::_weeks_" : ["тиждень","тижнів","тижнів","тижні"],
    "No reminders yet" : "Жодного нагадування поки що",
    "Availability of attendees, resources and rooms" : "Доступність учасників, ресурсів і приміщень",
    "Free" : "Вільно",
    "Busy (tentative)" : "Зайнято (попередньо)",
    "Busy" : "Зайнято",
    "Out of office" : "Поза межами офісу",
    "Unknown" : "Невідомо",
    "Create Talk room for this event" : "Створити Кімнату переговорів для цієї події",
    "Show busy times" : "Показати зайнятий час",
    "Successfully appended link to talk room to description." : "Успішно додано посилання на Кімнату переговорів до опису події.",
    "Error creating Talk room" : "Помилка при створенні Кімнати переговорів",
    "Chairperson" : "Голова зборів",
    "Required participant" : "Обов'язковий учасник",
    "Optional participant" : "Необов'язковий учасник",
    "Non-participant" : "Не-учасник",
    "Remove attendee" : "Вилучити учасника",
    "No match found" : "Жодного не знайдено",
    "No attendees yet" : "Поки жодного учасника",
    "(organizer)" : "(організатор)",
    "Remove color" : "Вилучити колір",
    "Event title" : "Назва події",
    "All day" : "Цілий день",
    "from {startDate}" : "з {startDate}",
    "from {startDate} at {startTime}" : "до {startDate} о {startTime}",
    "to {endDate}" : "до {endDate}",
    "to {endDate} at {endTime}" : "до {endDate} о {endTime}",
    "End repeat" : "Закінчення повторів",
    "Select to end repeat" : "Вибрати до кінця повторів",
    "never" : "ніколи",
    "on date" : "у дату",
    "after" : "після",
    "_time_::_times_" : ["раз","разів","разів","рази"],
    "first" : "перший",
    "third" : "третій",
    "fourth" : "четвертий",
    "fifth" : "п'ятий",
    "second to last" : "з другого до останнього",
    "last" : "останній",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Зміни до повторюваного набору застосуються лише до поточного і наступних випадків.",
    "Repeat" : "Повторювати",
    "Repeat every" : "Повторювати кожні",
    "By day of the month" : "За днем місяця",
    "On the" : "У",
    "_month_::_months_" : ["місяць","місяців","місяців","місяці"],
    "_year_::_years_" : ["рік","років","років","роки"],
    "Monday" : "понеділок",
    "weekday" : "робочі дні",
    "weekend day" : "вихідні дні",
    "Summary" : "Загалом",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Налаштування повторюванності даної події не повністю підтримуються у Nextcloud. В разі редагування налаштувань повторюваності деякі з повторів можуть зникнути.",
    "More" : "Більше",
    "Save" : "Зберегти",
    "Update" : "Оновити",
    "Update this occurrence" : "Оновити даний повтор",
    "Update this and all future" : "Оновити цей і всі наступні",
    "Public calendar does not exist" : "Публічний календар не існує",
    "Maybe the share was deleted or has expired?" : "Можливо спільний доступ було закрито або застаріло?",
    "Please select a timezone:" : "Будь-ласка вкажіть часовий пояс:",
    "Pick a time" : "Вибрати час",
    "Pick a date" : "Вибрати дату",
    "from {formattedDate}" : "з {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "з {formattedDate} о {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} о {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} о {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} о {formattedTime}",
    "Please enter a valid date" : "Будь-ласка вкажіть коректну дату",
    "Please enter a valid date and time" : "Будь-ласка вкажіть коректну дату і час",
    "Type to search timezone" : "Наберіть для пошуку часового поясу",
    "Personal" : "Особисте",
    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Автоматичне визначення часового поясу вибрало для вас UTC. Найвірогідніша причина - налаштування безпеки вашого браузера. Будь-ласка вкажіть ваш часовий пояс у налаштуваннях календаря.",
    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Налаштований часовий пояс ({timezoneId}) не знайдено. Автоматично встановлено UTC.\nБудь-ласка змініть налаштування вашого часового поясу і повідомте про цей випадок.",
    "Delete this occurrence" : "Вилучити повторення",
    "Delete this and all future" : "Вилучити це й наступні повторення",
    "Details" : "Деталі",
    "Attendees" : "Учасників",
    "Reminders" : "Нагадування",
    "Close" : "Закрити",
    "Show more details" : "Збільшити деталізацію",
    "Subscribe to {name}" : "Підписатися на {name}",
    "Download {name}" : "Завантажити {name}",
    "Anniversary" : "Річниця",
    "Appointment" : "Призначення",
    "Business" : "Робота",
    "Education" : "Навчання",
    "Holiday" : "Вихідний",
    "Meeting" : "Зустріч",
    "Miscellaneous" : "Різне",
    "Non-working hours" : "Неробочий час",
    "Not in office" : "Поза офісом",
    "Phone call" : "Телефонний дзвінок",
    "Sick day" : "Лікарняний",
    "Special occasion" : "Особлива подія",
    "Travel" : "Подорож",
    "Vacation" : "Відпустка",
    "Midnight on the day the event starts" : "Початок доби у день старту події",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n день до початку події о {formattedHourMinute}","%n днів до початку події о {formattedHourMinute}","%n днів до початку події о {formattedHourMinute}","%n дні до початку події о {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n тиждень до початку події о {formattedHourMinute}","%n тижнів до початку події о {formattedHourMinute}","%n тижнів до початку події о {formattedHourMinute}","%n тижні до початку події о {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "у день події о {formattedHourMinute}",
    "at the event's start" : "на початку події",
    "at the event's end" : "у кінці події",
    "{time} before the event starts" : "{time} до початку події",
    "{time} before the event ends" : "{time} до завершення події",
    "{time} after the event starts" : "{time} після початку події",
    "{time} after the event ends" : "{time} після завершення події",
    "on {time}" : "о {time}",
    "on {time} ({timezoneId})" : "о {time} ({timezoneId})",
    "Week {number} of {year}" : "Тиждень {number} з {year} року",
    "Does not repeat" : "Не повторюється",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Monthly" : "Щомісяця",
    "Yearly" : "Щороку",
    "_Every %n day_::_Every %n days_" : ["Кожен %n день","Кожні %n днів","Кожні %n днів","Кожні %n дні"],
    "_Every %n week_::_Every %n weeks_" : ["Кожен %n тиждень","Кожні %n тижнів","Кожні %n тижнів","Кожні %n тижні"],
    "_Every %n month_::_Every %n months_" : ["Кожен %n місяць","Кожні %n місяців","Кожні %n місяців","Кожні %n місяці"],
    "_Every %n year_::_Every %n years_" : ["Кожен %n рік","Кожні %n років","Кожні %n років","Кожні %n роки"],
    "_on {weekday}_::_on {weekdays}_" : ["у {weekdays}","у {weekdays}","у {weekdays}","у {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["у наступний день {dayOfMonthList}","у наступні дні {dayOfMonthList}","у наступні дні {dayOfMonthList}","у наступні дні {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "у {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "у {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "у {monthNames} у {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n раз","%n разів","%n разів","%n рази"],
    "Untitled task" : "Завдання без назви",
    "Please ask your administrator to enable the Tasks App." : "Зверніться до вашого адміністратора щодо увімкнення застосунку Завдання",
    "_+%n more_::_+%n more_" : ["+%n раз ще","+%n разів ще","+%n разів ще","+%n рази ще"],
    "When shared show" : "Показувати при поширенні",
    "When shared show full event" : "При поширенні показувати подію повністю",
    "When shared show only busy" : "При поширенні показувати тільки зайнятий час",
    "When shared hide this event" : "При поширенні приховати цю подію",
    "The visibility of this event in shared calendars." : "Видимість цієї події при поширенні календаря.",
    "Location" : "Місце",
    "Add a location" : "Додати розташування",
    "Description" : "Опис",
    "Add a description" : "Додати опис",
    "Status" : "Статус",
    "Confirmed" : "Підтверджено",
    "Tentative" : "Попередній",
    "Canceled" : "Скасовано",
    "Confirmation about the overall status of the event." : "Підтвердження загального статусу події.",
    "Show as" : "Показати як",
    "Take this event into account when calculating free-busy information." : "Брати до уваги цю подію при розрахунку інформації про вильний/зайнятий час.",
    "Categories" : "Категорії",
    "Categories help you to structure and organize your events." : "Категорії допомагають структурувати і впорядковувати ваші події.",
    "Search or add categories" : "Знайти або додати категорії",
    "Add this as a new category" : "Додати як нову категорію",
    "Custom color" : "Довільний колір",
    "Special color of this event. Overrides the calendar-color." : "Особливий колір для цієї події. Перезаписати колір календаря.",
    "Chat room for event" : "Кімната спілкування для події",
    "Imported {filename}" : "Імпортований {filename}",
    "Meditation" : "Медитація",
    "Relaxing" : "Розслаблення",
    "Relax" : "Розслабитися",
    "Presentation" : "Презентація",
    "Present" : "Презентувати",
    "Camping" : "Лагер",
    "Camp" : "Лагер",
    "Movie" : "Фільм",
    "Cinema" : "Кінотеатр",
    "Graduation" : "Випускний",
    "Brainstorm" : "Мозговий штурм",
    "Baseball" : "Бейзбол",
    "Meet" : "Зустріти",
    "Planning" : "Планується",
    "Pointing" : "Призначено",
    "Retrospective" : "Ретроспектива",
    "Review" : "На перегляд",
    "Office" : "Офіс",
    "Contributor week" : "Тиждень постачальника",
    "Mail" : "Пошта",
    "Soccer" : "Футбол",
    "Football" : "Американський футбол",
    "Gaming" : "Ігри",
    "Drive" : "Їхати автомобілем",
    "Bicycle" : "Їхати велосипедом",
    "Cycle" : "Їхати колесами",
    "Biking" : "Їхати мотоциклом",
    "Podcast" : "Подкаст",
    "Basketball" : "Баскетбол",
    "Fishing" : "Рибалити",
    "Hiking" : "Пішки",
    "Hike" : "Похід",
    "Art" : "Мистецтво",
    "Exhibition" : "Виставка",
    "Museum" : "Музей",
    "Pilates" : "Пілатес",
    "Park" : "Парк",
    "Studying" : "Навчання",
    "Doctor" : "Лікар",
    "Health" : "Здоров'я",
    "Dentist" : "Стоматолог",
    "Interview" : "Співбесіда",
    "Training" : "Тренування",
    "Practice" : "Практика",
    "Sports" : "Спорт",
    "Exercise" : "Вправи",
    "Work out" : "Тренажери",
    "Working out" : "У тренажерному залі",
    "Gym" : "Тренажерний зал",
    "Barber" : "Перукар",
    "Haircut" : "Зачіска",
    "Exam" : "Іспит",
    "Working" : "Працюю",
    "New Years Eve" : "Новий рік",
    "NYE" : "Новий рік",
    "Fireworks" : "Феєрверки",
    "Running" : "Бігаю",
    "Go for a run" : "Пробіжка",
    "Marathon" : "Марафон",
    "Video-conference" : "Відеоконференція",
    "Conference-call" : "Конференц-виклик",
    "Video-call" : "Відеовиклик",
    "Video-chat" : "Відеочат",
    "Video-meeting" : "Відеозустріч",
    "Call" : "Дзвінок",
    "Calling" : "Телефоную",
    "Christmas" : "Різдво",
    "Conference" : "Конференція",
    "Pizza" : "Піцца",
    "Travelling" : "Подорожую",
    "Journey" : "Подорож",
    "Collaborate" : "Співпраця",
    "Pair" : "Пара",
    "Lecture" : "Лекція",
    "Seminar" : "Семінар",
    "Photograph" : "Фотограф",
    "Party" : "Вечірка",
    "Celebration" : "Святкування",
    "Celebrate" : "Святкування",
    "Shopping" : "Шопінг",
    "Skate" : "Ковзани",
    "Skateboard" : "Скейт",
    "Wine tasting" : "Дегустація",
    "Golf" : "Гольф",
    "Dinner" : "Вечеря",
    "Lunch" : "Обід",
    "Global" : "Загальний"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
